#How to Create a Population Pyramid in R?
#https://www.geeksforgeeks.org/how-to-create-a-population-pyramid-in-r/

#Modify the legend of a graph made with ggplot2
#http://www.cookbook-r.com/Graphs/Legends_(ggplot2)/

#Install packages
install.packages("readr")
install.packages("ggplot2")
install.packages("dplyr")

#Load package readr to import CSV file
library(readr)

#Load package ggplot2 and dplyr
library(ggplot2)
library(dplyr)

#Change work directory
setwd("~/Desktop")

#Import CSV file
pop_age_sex <- read_csv("Population_pyramids.csv")
View(pop_age_sex)

##############################
#Create population pyramid
#Change male population to negative

#Syntax:
#ggplot(df, aes(x = age, y = population, fill)) + geom_bar(stat = “identity”)
#       + coord_flip() + labs( title, x, y) + scale_x/y_continuous() + scale_fill_manual()

#Parameters:
#df: determines the data frame that contains population data.
#gender, age and population: determines the columns of df data frame.
#fill: determines the variable according to which bars are to be colored.
#title: determines the title of the plot.
#x and y: determines the label of x and y axis respectively.
#scale_x/y_continuous(limits, breaks): determines the limits and axis breaks of the x and y-axis.
#scale_fill_manual(values, name, breaks, labels): use customized color scale for bars

pop_age_sex %>%mutate(
  population = ifelse(gender=="M", population*(-1),
                      population*1))%>%
  ggplot(aes(x=age, y=population, fill=gender)) +
  geom_bar(stat="identity") +
  coord_flip()+
  scale_y_continuous(limits = c(-4,4),
                     breaks = seq(-4, 4, by = 0.5))+
  scale_x_continuous(limits = c(-5,90),
                     breaks = seq(0, 85, by = 5))+
  scale_fill_manual(values=c("navy","red"),
                    name="",
                    breaks=c("M","F"),
                    labels=c("Male","Female"))+
  labs(title = "Age-sex structure, United States, 2021",
       x = "Age group", y = "Percent")
